@@ -1,13 +1,13 @@
 /**
  * @file     str.h
  * @brief    SCEW string functions
- * @author   Aleix Conchillo Flaque <aleix@member.fsf.org>
+ * @author   Aleix Conchillo Flaque <aconchillo@gmail.com>
  * @date     Sun Dec 01, 2002 13:05
  * @ingroup  SCEWString
  *
  * @if copyright
  *
- * Copyright (C) 2002-2009 Aleix Conchillo Flaque
+ * Copyright (C) 2002-2013 Aleix Conchillo Flaque
  *
  * SCEW is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -312,7 +312,7 @@ extern SCEW_API scew_bool scew_isempty (XML_Char const *src);
  *
  * @ingroup SCEWString
  */
-extern XML_Char* scew_strescape (XML_Char const *src);
+extern SCEW_API XML_Char* scew_strescape (XML_Char const *src);
 
 #ifdef __cplusplus
 }
